declare type SymbolType = 'type' | 'interface' | 'enum';
declare type UnusedFileIssues = Set<string>;
declare type UnusedExportIssues = Record<string, Record<string, Issue>>;
declare type UnresolvedDependencyIssues = Record<string, Record<string, Issue>>;
declare type UnusedDependencyIssues = Set<string>;
export declare type Issue = {
    filePath: string;
    symbol: string;
    symbols?: string[];
    symbolType?: SymbolType;
};
export declare type Issues = {
    files: UnusedFileIssues;
    dependencies: UnusedDependencyIssues;
    devDependencies: UnusedDependencyIssues;
    unresolved: UnresolvedDependencyIssues;
    exports: UnusedExportIssues;
    types: UnusedExportIssues;
    nsExports: UnusedExportIssues;
    nsTypes: UnusedExportIssues;
    duplicates: UnusedExportIssues;
};
declare type IssueType = keyof Issues;
export declare type ProjectIssueType = Extract<IssueType, 'files' | 'dependencies' | 'devDependencies'>;
export declare type SymbolIssueType = Exclude<IssueType, ProjectIssueType>;
export declare type IssueGroup = 'files' | 'dependencies' | 'unlisted' | 'exports' | 'nsExports' | 'types' | 'nsTypes' | 'duplicates';
declare type BaseLocalConfiguration = {
    entryFiles: string[];
    projectFiles: string[];
};
export declare type LocalConfiguration = BaseLocalConfiguration & {
    dev?: boolean | BaseLocalConfiguration;
    entryFiles: string[];
    projectFiles: string[];
    include?: string[];
    exclude?: string[];
};
export declare type ImportedConfiguration = LocalConfiguration | Record<string, LocalConfiguration>;
export declare type Configuration = LocalConfiguration & {
    workingDir: string;
    report: {
        [key in IssueGroup]: boolean;
    };
    dependencies: string[];
    devDependencies: string[];
    isDev: boolean;
    tsConfigFilePath: undefined | string;
    tsConfigPaths: string[];
    ignorePatterns: string[];
    isShowProgress: boolean;
    jsDocOptions: {
        isReadPublicTag: boolean;
    };
};
export {};
