"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.readIgnorePatterns = exports.convertPattern = void 0;
const promises_1 = __importDefault(require("node:fs/promises"));
const node_path_1 = __importDefault(require("node:path"));
const fs_1 = require("./fs");
const path_1 = require("./path");
const convertPattern = (pattern) => (pattern.startsWith('!') ? pattern.substring(1) : `!${pattern}`);
exports.convertPattern = convertPattern;
const readIgnoreFile = async (filePath) => {
    let contents = '';
    try {
        contents = (await promises_1.default.readFile(filePath)).toString();
    }
    catch (error) {
    }
    return contents.split(/\r?\n/).filter(line => line && !line.startsWith('#'));
};
const traverseDirs = async (rootDir, currentDir, patterns = []) => {
    const gitIgnorePath = node_path_1.default.join(currentDir, '.gitignore');
    const parentDir = node_path_1.default.resolve(currentDir, '..');
    if (await (0, fs_1.isFile)(gitIgnorePath)) {
        (await readIgnoreFile(gitIgnorePath))
            .map(pattern => (0, path_1.addWorkingDirToPattern)(currentDir, pattern))
            .forEach(pattern => patterns.push(pattern));
    }
    if (rootDir === currentDir || parentDir === '/')
        return patterns;
    return traverseDirs(rootDir, parentDir, patterns);
};
const readIgnorePatterns = async (cwd, workingDir) => {
    const patterns = await traverseDirs(cwd, workingDir);
    return patterns.map(exports.convertPattern);
};
exports.readIgnorePatterns = readIgnorePatterns;
