"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.partitionSourceFiles = exports.createProject = void 0;
const ts_morph_1 = require("ts-morph");
const path_1 = require("./path");
const createProject = async (configuration, paths) => {
    const { tsConfigFilePath, ignorePatterns } = configuration;
    const tsConfig = tsConfigFilePath ? { tsConfigFilePath } : { compilerOptions: { allowJs: true } };
    const workspace = new ts_morph_1.Project({
        ...tsConfig,
        skipAddingFilesFromTsConfig: true,
        skipFileDependencyResolution: true,
    });
    if (paths) {
        const resolvedPaths = (0, path_1.resolvePaths)(configuration, paths);
        workspace.addSourceFilesAtPaths([...resolvedPaths, ...ignorePatterns]);
    }
    return workspace;
};
exports.createProject = createProject;
const partitionSourceFiles = (projectFiles, productionFiles) => {
    const productionFilePaths = productionFiles.map(file => file.getFilePath());
    const usedFiles = [];
    const unusedFiles = [];
    projectFiles.forEach(projectFile => {
        if (productionFilePaths.includes(projectFile.getFilePath())) {
            usedFiles.push(projectFile);
        }
        else {
            unusedFiles.push(projectFile);
        }
    });
    return [usedFiles, unusedFiles];
};
exports.partitionSourceFiles = partitionSourceFiles;
